import { WebDavProtocol } from "@/models/WebDavProtocol.js";
import { WebDavProtocolItem } from "@/models/WebDavProtocolItem.js";
import { AllOs, AllBrowsers } from "@/settings/webDavProtocol.js";
import { ITHit } from "webdav.client";
import webDavSettings from "@/WebDavSettings.js";

export default {
  /**
   * Gets Protocol
   * @returns {WebDavProtocol}
   */
  getProtocol() {
    var webDavProtocol = null;
    let currentBrowserProtocol = this.getCurrentBrowserProtocol();
    let currentOsProtocol = this.getCurrentOsProtocol();
    webDavProtocol = new WebDavProtocol(
      currentOsProtocol,
      currentBrowserProtocol,
      currentOsProtocol
        ? AllOs.filter(c => c.CssClass != currentOsProtocol.CssClass)
        : AllOs,
      currentBrowserProtocol
        ? AllBrowsers.filter(c => c.CssClass != currentBrowserProtocol.CssClass)
        : AllBrowsers
    );
    return webDavProtocol;
  },
  /**
   * Gets current browser Protocol item
   * @returns {WebDavProtocolItem}
   */
  getCurrentBrowserProtocol() {
    const userAgent = navigator.userAgent;
    var currentBrowserProtocol = null;
    if (userAgent.match(/firefox|fxios/i)) {
      currentBrowserProtocol = AllBrowsers.filter(
        c => c.CssClass == "mozilla-firefox"
      ).shift();
    } else if (userAgent.match(/edg/i)) {
      currentBrowserProtocol = AllBrowsers.filter(
        c => c.CssClass == "edge-chromium"
      ).shift();
    } else if (userAgent.match(/chrome|chromium|crios/i)) {
      currentBrowserProtocol = AllBrowsers.filter(
        c => c.CssClass == "goole-chrome"
      ).shift();
    } else if (userAgent.match(/trident/i)) {
      currentBrowserProtocol = new WebDavProtocolItem(
        "The extension is not required for Internet Explorer.",
        "",
        "",
        "not-required-internet-explorer"
      );
    }

    return currentBrowserProtocol;
  },
  /**
   * Gets current OS Protocol item
   * @returns {WebDavProtocolItem}
   */
  getCurrentOsProtocol() {
    var currentOsProtocol = null;
    if (ITHit.DetectOS.OS === "Windows") {
      currentOsProtocol = AllOs.filter(c => c.CssClass == "window").shift();
    } else if (ITHit.DetectOS.OS === "Linux") {
      currentOsProtocol = AllOs.filter(c => c.CssClass == "linux").shift();
    } else if (ITHit.DetectOS.OS === "MacOS") {
      currentOsProtocol = AllOs.filter(c => c.CssClass == "mac-os").shift();
    }
    return currentOsProtocol;
  },
  /**
   * Is dav protocol supported
   * @returns {Boolean}
   */
  isDavProtocolSupported() {
    return ITHit.WebDAV.Client.DocManager.IsDavProtocolSupported();
  },
  /**
   * Is microsoft office document
   * @returns {Boolean}
   */
  isMicrosoftOfficeDocument(sHref) {
    return ITHit.WebDAV.Client.DocManager.IsMicrosoftOfficeDocument(sHref);
  },

  getInstallerFileUrl() {
    if (ITHit.DetectOS.OS === "Windows") {
      return "ms-windows-store://pdp/?ProductId=9nqb82r5hmnh";
    } else if (ITHit.DetectOS.OS === "MacOS") {
      return "https://apps.apple.com/us/app/webdav-drive/id6502366145";
    }
    return (
      webDavSettings.ApplicationProtocolsPath +
      ITHit.WebDAV.Client.DocManager.GetProtocolInstallFileNames()[0]
    );
  }
};
